<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi" sourcelanguage="en">
<context>
    <name>Bubble</name>
    <message>
        <location filename="../dde-osd/src/notification/bubble.cpp" line="325"/>
        <source>1 new message</source>
        <translation>1 tin nhắn mới</translation>
    </message>
</context>
<context>
    <name>BubbleItem</name>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="232"/>
        <source>Just Now</source>
        <translation>Ngay bây giờ</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="234"/>
        <source>%1 minutes ago</source>
        <translation>%1 phút trước</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="236"/>
        <source>%1 hours ago</source>
        <translation>%1 giờ trước</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="239"/>
        <source>Yesterday </source>
        <translation>Ngày hôm qua</translation>
    </message>
</context>
<context>
    <name>Content</name>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="272"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="273"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>DMemoryWarningDialog</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="49"/>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="51"/>
        <source>Release</source>
        <translation>Phát hành</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="55"/>
        <source>This application will be ended, please make sure your data has been saved!</source>
        <translation>Ứng dụng này sẽ kết thúc, vui lòng đảm bảo dữ liệu của bạn đã được lưu!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="56"/>
        <source>Please save your document, text and spreadsheet</source>
        <translation>Vui lòng lưu tài liệu, văn bản và bảng tính của bạn</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="89"/>
        <source>Continue</source>
        <translation>Tiếp tục</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="110"/>
        <source>Insufficient system memory, please end some applications to avoid getting stuck.</source>
        <translation>Bộ nhớ hệ thống không đủ, vui lòng tắt một số ứng dụng để tránh bị lỗi.</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="222"/>
        <source>Continue to run %1, %2MB memory is required</source>
        <translation>Tiếp tục chạy %1, yêu cầu %2 MB bộ nhớ </translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="225"/>
        <source>Continue to open browser tab, %1MB memory is required</source>
        <translation>Để tiếp tục mở tab trình duyệt, yêu cầu %1 MB bộ nhớ</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="228"/>
        <source>To continue the operation, %1MB memory is required</source>
        <translation>Để tiếp tục cần %1 MB bộ nhớ</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="234"/>
        <source>Your current memory is sufficient enough, continue to run %1?</source>
        <translation>Bộ nhớ hiện tại của bạn đã đủ, tiếp tục chạy %1?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="237"/>
        <source>Your current memory is sufficient enough, continue to open browser tab?</source>
        <translation>Bộ nhớ hiện tại của bạn đã đủ, tiếp tục mở tab trình duyệt?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="240"/>
        <source>Your current memory is sufficient enough, continue the operation?</source>
        <translation>Bộ nhớ hiện tại của bạn đã đủ, tiếp tục hoạt động?</translation>
    </message>
</context>
<context>
    <name>DisplayModeProvider</name>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="292"/>
        <source>Only on %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="294"/>
        <source>Duplicate</source>
        <translation>Lặp lại</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="296"/>
        <source>Extend</source>
        <translation>Mở rộng</translation>
    </message>
</context>
<context>
    <name>KBLayoutIndicator</name>
    <message>
        <location filename="../dde-osd/src/kblayoutindicator.cpp" line="161"/>
        <source>Add keyboard layout</source>
        <translation>Thêm bố cục bàn phím</translation>
    </message>
</context>
<context>
    <name>NetworkSecretDialog</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="107"/>
        <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
        <translation>Yêu cầu mật khẩu để kết nối &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="179"/>
        <source>Wrong password, please enter again!</source>
        <translation>Sai mật khẩu, vui lòng nhập lại!</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Connect</source>
        <translation>Kết nối</translation>
    </message>
</context>
<context>
    <name>NotifyCenterWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifycenterwidget.cpp" line="97"/>
        <source>Notification Center</source>
        <translation>Trung tâm Thông báo</translation>
    </message>
</context>
<context>
    <name>NotifyWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifywidget.cpp" line="40"/>
        <source>No system notifications</source>
        <translation>Không có thông báo hệ thống</translation>
    </message>
</context>
<context>
    <name>OSDProvider</name>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="138"/>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="125"/>
        <source>WLAN on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="126"/>
        <source>WLAN off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="128"/>
        <source>Caps Lock on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="129"/>
        <source>Caps Lock off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="131"/>
        <source>Numeric keypad on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="132"/>
        <source>Numeric keypad off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="134"/>
        <source>Touchpad on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="135"/>
        <source>Touchpad off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="136"/>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="140"/>
        <source>Airplane mode on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="141"/>
        <source>Airplane mode off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="143"/>
        <source>Mute on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="144"/>
        <source>Mute off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="146"/>
        <source>Balanced power</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="147"/>
        <source>Power saver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="148"/>
        <source>High performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="150"/>
        <source>Window effect enabled</source>
        <translation>Hiệu ứng của sổ được cho phép</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="151"/>
        <source>Window effect disabled</source>
        <translation>Hiệu ứng của sổ bị vô hiệu hóa</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="152"/>
        <source>Failed to enable window effects</source>
        <translation>Mở các hiệu ứng cửa sổ thất bại</translation>
    </message>
</context>
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="57"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="146"/>
        <source>Passwords do not match</source>
        <translation>Mật khẩu không phù hợp</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="65"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="86"/>
        <source>New Password</source>
        <translation>Mật mã mới</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="120"/>
        <source>Repeat Password</source>
        <translation>Lặp lại Mật mã</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Password Hint</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="137"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="138"/>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="139"/>
        <source>Optional</source>
        <translation>Không bắt buộc</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="221"/>
        <source>Strong</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="231"/>
        <source>Medium</source>
        <translation>Trung bình</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="240"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="253"/>
        <source>A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="244"/>
        <source>Weak</source>
        <translation>Yếu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="255"/>
        <source>Error occurred when reading the configuration files of password rules!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PinCodeDialog</name>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="40"/>
        <source>The PIN for connecting to the Bluetooth device is:</source>
        <translation>PIN để kết nối với thiết bị Bluetooth là:</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>ProcessInfoModel</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/processinfomodel.cpp" line="111"/>
        <source>End</source>
        <translation>Kết thúc</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="76"/>
        <source>Password cannot be empty</source>
        <translation>Mật khẩu không được để trống</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="77"/>
        <source>Password must have at least %1 characters</source>
        <translation>Mật khẩu phải có ít nhất %1 ký tự</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="78"/>
        <source>Password must be no more than %1 characters</source>
        <translation>Mật khẩu không được nhiều hơn %1 ký tự</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="79"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Mật khẩu chỉ được chứa các chữ cái tiếng Anh (sensitivedo chữ hoa/thường), số hoặc ký tự đặc biệt (~`!@#$%^&amp;*()-_+=|{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="80"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>Không sử dụng nhiều hơn %1 ký tự đối xứng</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="81"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>Không sử dụng nhiều hơn %1 ký tự đồng điệu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Không sử dụng nhiều hơn %1 ký tự lặp</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="87"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Mật khẩu phải chứa chữ cái hoa, chữ cái thường, số và ký tự (~`!@#$%^&amp;*()-_+=|{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="88"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Mật khẩu không được chứa nhiều hơn 4 ký tự đối xứng</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="89"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="92"/>
        <source>Do not use common words and combinations as password</source>
        <translation>Không sử dụng từ vựng thông thường và các kết hợp làm mật khẩu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="90"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="91"/>
        <source>Create a strong password please</source>
        <translation>Tạo một mật khẩu mạnh mẽ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="97"/>
        <source>It does not meet password rules</source>
        <translation>Không tuân theo quy tắc mật khẩu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="43"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="49"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="59"/>
        <source>Password</source>
        <translation>Mật mã</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="44"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="45"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="46"/>
        <source>Key</source>
        <translation>Chìa khóa</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="47"/>
        <source>key</source>
        <translation>khóa key</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="55"/>
        <source>Private Pwd</source>
        <translation>Pwd Cá nhân</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="58"/>
        <source>Proxy Password</source>
        <translation>Mật khẩu proxy</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="60"/>
        <source>Group Password</source>
        <translation>Nhóm mật khẩu</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="110"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="112"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <source>Security Questions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="156"/>
        <source>Reset Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="157"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <source>Next</source>
        <translation>Kế tiếp</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Reset Password By Union ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="161"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="206"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="213"/>
        <source>Reset</source>
        <translation>Thiết đặt lại</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="167"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <source>Confirm and Reset</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="264"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="129"/>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>Who do you love the most in this world?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite animal?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your favorite song?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="136"/>
        <source>What&apos;s your nickname?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="186"/>
        <source>Wrong answer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="201"/>
        <source>Keep the answer under 30 characters</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SuspendDialog</name>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <source>External monitor detected, suspend?</source>
        <translation>Màn hình bên ngoài được phát hiện, có dừng không?</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="65"/>
        <source>%1s</source>
        <translation>%1s</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Suspend</source>
        <translation>Dừng</translation>
    </message>
</context>
<context>
    <name>TouchscreenSetting</name>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="45"/>
        <source>Select your touch screen</source>
        <translation>Chọn màn hình cảm ứng</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="55"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="63"/>
        <source>Phone/Email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="69"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="136"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="289"/>
        <source>Get Code</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="89"/>
        <source>Connecting to the Internet...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="101"/>
        <source>The user account is not linked to Union ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="114"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Không có kết nối mạng, xin hãy thử lại...</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="134"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="135"/>
        <source>Required</source>
        <translation>Cần thiết</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="170"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="185"/>
        <source>Phone/Email format is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="239"/>
        <source>System error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="241"/>
        <source>Login expired, please sign in to the Union ID again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="243"/>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="245"/>
        <source>You have reached the number limit to get the code today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>The Union ID is not linked to a user account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="255"/>
        <source>It cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="292"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="334"/>
        <source>Resend (%1s)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="353"/>
        <source>Failed to get the code</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="376"/>
        <source>Wrong verification code</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateContent</name>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="45"/>
        <source>Welcome, system updated successfully</source>
        <translation>Xin chào, hệ thống đã cập nhật thành công</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="46"/>
        <source>Current Edition:</source>
        <translation>Phiên bản hiện tại:</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="47"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>WMChooser</name>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="57"/>
        <source>Effect Mode</source>
        <translation>Chế độ Hiệu quả</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="60"/>
        <source>Normal Mode</source>
        <translation>Chế độ bình thường</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="68"/>
        <source>It has detected that you are using a virtual machine, which will affect the system performance and operation experience, for a smooth experience, Normal Mode is recommended</source>
        <translation>Phát hiện bạn đang sử dụng máy ảo, điều này sẽ ảnh hưởng đến hiệu suất hoạt động và trải nghiệm vận hành của hệ thống, để có trải nghiệm mượt mà, khuyến nghị bật chế độ bình thường</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="71"/>
        <source>Effect Mode: Have a delicate experience. Normal Mode: Enjoy the fast performance</source>
        <translation>Chế độ hiệu ứng: Có một trải nghiệm tinh tế. Chế độ bình thường: Tận hưởng hiệu suất nhanh</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="64"/>
        <source>Friendly Reminder</source>
        <translation>Nhắc nhở Thân thiện</translation>
    </message>
</context>
<context>
    <name>WarningDialog</name>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="38"/>
        <source>Kindly Reminder</source>
        <translation>Nhắc nhở Thân thiện</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="39"/>
        <source>This application cannot run without window effect</source>
        <translation>Ứng dụng này không thể chạy mà không có hiệu ứng cửa sổ</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="43"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../dde-lowpower/src/window.cpp" line="41"/>
        <source>Low battery, please plug in</source>
        <translation>Pin yếu, xin hãy gắn dây vào</translation>
    </message>
</context>
</TS>